==> eiffelstudio-18.07.10.1981.tar: F_code/C16/if777.c <==
/*
 * Code for class IF_EXPRESSION_AS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "if777.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IF_EXPRESSION_AS}.initialize */
void F1469_17173 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6, EIF_REFERENCE arg7, EIF_REFERENCE arg8)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(9);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLR(4,arg4);
	RTLR(5,arg5);
	RTLR(6,arg6);
	RTLR(7,arg7);
	RTLR(8,arg8);
	RTLIU(9);
	
	RTEAA("initialize", 1468, Current, 0, 8, 23897);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg3;
	RTHOOK(4);
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg4;
	RTHOOK(5);
	RTAR(Current, arg5);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg5;
	RTHOOK(6);
	if ((EIF_BOOLEAN)(arg6 != NULL)) {
		RTHOOK(7);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg6) + O13206[Dtype(arg6)-1425]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(8);
	if ((EIF_BOOLEAN)(arg7 != NULL)) {
		RTHOOK(9);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg7) + O13206[Dtype(arg7)-1425]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(10);
	if ((EIF_BOOLEAN)(arg8 != NULL)) {
		RTHOOK(11);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg8) + O13206[Dtype(arg8)-1425]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(12);
	RTLE;
	RTEE;
}

/* {IF_EXPRESSION_AS}.process */
void F1469_17174 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("process", 1468, Current, 0, 1, 23879);
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4221[Dtype(arg1)-516])(RTCW(arg1), Current);
	RTHOOK(2);
	RTEE;
}

/* {IF_EXPRESSION_AS}.is_detachable_expression */
EIF_BOOLEAN F1469_17175 (EIF_REFERENCE Current)
{
	return (EIF_BOOLEAN) EIF_TRUE;
}

/* {IF_EXPRESSION_AS}.if_keyword */
EIF_REFERENCE F1469_17179 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc2);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("if_keyword", 1468, Current, 2, 1, 23884);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_);
	RTHOOK(2);
	tb1 = '\0';
	tb2 = F665_6302(RTCW(arg1), loc1);
	if (tb2) {
		tr1 = F665_6297(RTCW(arg1), loc1);
		loc2 = tr1;
		loc2 = RTRV(eif_new_type(1430, 0x00),loc2);
		tb1 = EIF_TEST(loc2);
	}
	if (tb1) {
		RTHOOK(3);
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) loc2;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

/* {IF_EXPRESSION_AS}.then_keyword */
EIF_REFERENCE F1469_17180 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc2);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("then_keyword", 1468, Current, 2, 1, 23885);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_1_);
	RTHOOK(2);
	tb1 = '\0';
	tb2 = F665_6302(RTCW(arg1), loc1);
	if (tb2) {
		tr1 = F665_6297(RTCW(arg1), loc1);
		loc2 = tr1;
		loc2 = RTRV(eif_new_type(1430, 0x00),loc2);
		tb1 = EIF_TEST(loc2);
	}
	if (tb1) {
		RTHOOK(3);
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) loc2;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

/* {IF_EXPRESSION_AS}.else_keyword */
EIF_REFERENCE F1469_17181 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc2);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("else_keyword", 1468, Current, 2, 1, 23886);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_2_);
	RTHOOK(2);
	tb1 = '\0';
	tb2 = F665_6302(RTCW(arg1), loc1);
	if (tb2) {
		tr1 = F665_6297(RTCW(arg1), loc1);
		loc2 = tr1;
		loc2 = RTRV(eif_new_type(1430, 0x00),loc2);
		tb1 = EIF_TEST(loc2);
	}
	if (tb1) {
		RTHOOK(3);
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) loc2;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

/* {IF_EXPRESSION_AS}.condition */
EIF_REFERENCE F1469_17183 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {IF_EXPRESSION_AS}.then_expression */
EIF_REFERENCE F1469_17184 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {IF_EXPRESSION_AS}.elsif_list */
EIF_REFERENCE F1469_17185 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {IF_EXPRESSION_AS}.else_expression */
EIF_REFERENCE F1469_17186 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {IF_EXPRESSION_AS}.end_keyword */
EIF_REFERENCE F1469_17187 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {IF_EXPRESSION_AS}.first_token */
EIF_REFERENCE F1469_17188 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("first_token", 1468, Current, 0, 1, 23893);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(arg1 != NULL)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current);
		Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R12603[Dtype(tr1)-1342])(RTCW(tr1), NULL);
	} else {
		RTHOOK(3);
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_) != ((EIF_INTEGER_32) 0L))) {
			RTHOOK(4);
			RTHOOK(5);
			RTLE;
			RTEE;
			return (EIF_REFERENCE) F1469_17179(Current, arg1);
		}
	}
	RTHOOK(6);
	RTLE;
	RTEE;
	return Result;
}

/* {IF_EXPRESSION_AS}.last_token */
EIF_REFERENCE F1469_17189 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("last_token", 1468, Current, 0, 1, 23894);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	Result = F1426_16674(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {IF_EXPRESSION_AS}.is_equivalent */
EIF_BOOLEAN F1469_17190 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("is_equivalent", 1468, Current, 0, 1, 23895);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	tb1 = '\0';
	tb2 = '\0';
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	if (F1342_15725(Current, *(EIF_REFERENCE *)(Current), tr1)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb2 = F1342_15725(Current, *(EIF_REFERENCE *)(Current + _REFACS_1_), tr1);
	}
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
		tb1 = F1342_15725(Current, *(EIF_REFERENCE *)(Current + _REFACS_3_), tr1);
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
		Result = F1342_15725(Current, *(EIF_REFERENCE *)(Current + _REFACS_2_), tr1);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit777 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C16/if777.c <==
/*
 * Code for class IF_EXPRESSION_AS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "if777.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IF_EXPRESSION_AS}.initialize */
void F1473_17393 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6, EIF_REFERENCE arg7, EIF_REFERENCE arg8)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(9);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLR(4,arg4);
	RTLR(5,arg5);
	RTLR(6,arg6);
	RTLR(7,arg7);
	RTLR(8,arg8);
	RTLIU(9);
	
	RTEAA("initialize", 1472, Current, 0, 8, 24145);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg3;
	RTHOOK(4);
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg4;
	RTHOOK(5);
	RTAR(Current, arg5);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg5;
	RTHOOK(6);
	if ((EIF_BOOLEAN)(arg6 != NULL)) {
		RTHOOK(7);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg6) + O13342[Dtype(arg6)-1424]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(8);
	if ((EIF_BOOLEAN)(arg7 != NULL)) {
		RTHOOK(9);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg7) + O13342[Dtype(arg7)-1424]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_1_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(10);
	if ((EIF_BOOLEAN)(arg8 != NULL)) {
		RTHOOK(11);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg8) + O13342[Dtype(arg8)-1424]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_2_) = (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(20);
	RTLE;
	RTEE;
}

/* {IF_EXPRESSION_AS}.process */
void F1473_17394 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("process", 1472, Current, 0, 1, 24146);
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3796[Dtype(RTCW(arg1))-296])(arg1, Current);
	RTHOOK(2);
	RTEE;
}

/* {IF_EXPRESSION_AS}.is_detachable_expression */
EIF_BOOLEAN F1473_17395 (EIF_REFERENCE Current)
{
	return (EIF_BOOLEAN) EIF_TRUE;
}

/* {IF_EXPRESSION_AS}.if_keyword */
EIF_REFERENCE F1473_17399 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc2);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("if_keyword", 1472, Current, 2, 1, 24151);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_);
	RTHOOK(2);
	tb1 = '\0';
	tb2 = F438_6035(RTCW(arg1), loc1);
	if (tb2) {
		tr1 = F438_6030(RTCW(arg1), loc1);
		loc2 = tr1;
		loc2 = RTRV(eif_new_type(1429, 0x00),loc2);
		tb1 = EIF_TEST(loc2);
	}
	if (tb1) {
		RTHOOK(3);
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) loc2;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

/* {IF_EXPRESSION_AS}.then_keyword */
EIF_REFERENCE F1473_17400 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc2);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("then_keyword", 1472, Current, 2, 1, 24152);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_1_);
	RTHOOK(2);
	tb1 = '\0';
	tb2 = F438_6035(RTCW(arg1), loc1);
	if (tb2) {
		tr1 = F438_6030(RTCW(arg1), loc1);
		loc2 = tr1;
		loc2 = RTRV(eif_new_type(1429, 0x00),loc2);
		tb1 = EIF_TEST(loc2);
	}
	if (tb1) {
		RTHOOK(3);
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) loc2;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

/* {IF_EXPRESSION_AS}.else_keyword */
EIF_REFERENCE F1473_17401 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc2);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("else_keyword", 1472, Current, 2, 1, 24153);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_2_);
	RTHOOK(2);
	tb1 = '\0';
	tb2 = F438_6035(RTCW(arg1), loc1);
	if (tb2) {
		tr1 = F438_6030(RTCW(arg1), loc1);
		loc2 = tr1;
		loc2 = RTRV(eif_new_type(1429, 0x00),loc2);
		tb1 = EIF_TEST(loc2);
	}
	if (tb1) {
		RTHOOK(3);
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) loc2;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

/* {IF_EXPRESSION_AS}.first_token */
EIF_REFERENCE F1473_17408 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("first_token", 1472, Current, 0, 1, 24160);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(arg1 != NULL)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current);
		Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R12835[Dtype(RTCW(tr1))-1351])(tr1, NULL);
	} else {
		RTHOOK(3);
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_0_0_0_) != ((EIF_INTEGER_32) 0L))) {
			RTHOOK(4);
			Result = F1473_17399(Current, arg1);
			RTHOOK(5);
			RTLE;
			RTEE;
			return (EIF_REFERENCE) Result;
		}
	}
	RTHOOK(6);
	RTLE;
	RTEE;
	return Result;
}

/* {IF_EXPRESSION_AS}.last_token */
EIF_REFERENCE F1473_17409 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("last_token", 1472, Current, 0, 1, 24161);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	Result = F1425_16824(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit777 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
